What is Invenio Framework? — Invenio 3.4.0a8 documentation

# What is Invenio Framework?

Invenio is an open source framework for building large-scale digital repositories.

Invenio is first and foremost a source code framework. It’s a framework that you can use to build a repository solution, but it is not by itself a final repository software. Using Invenio requires you to develop code.

If you’re looking for a repository solution, checkout InvenioRDM.

If you’re looking for a Integrated Library System (ILS), checkout InvenioILS.

Several repositories have been built on top of Invenio v3, including e.g.:

- Zenodo - General purpose research data repository.

- CERN Open Data - Open data repository for CERN.

- CERN Videos - Digital Assets Management system with video encoding support.